<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        :paramObj="paramObj"
        ref="warehouseStockTable"
      >
        <template #toolbar>
          <el-button
            v-if="permissions.warehouse_stock_scm"
            @click="pushScm()"
            type="primary"
            style="margin-left:10px;"
            >成品推送SCM
          </el-button>
        </template>
      </ttable>
      <!-- 创建主生产计划 -->
      <stock-table
        v-if="stockVisible"
        ref="stock"
        @refreshDataList="getData"
      ></stock-table>
      <PrintLabelForm
        :currshowlist.sync="showPrintLabelForm"
        :printLabelInfo="printLabelInfo"
      />
      <SmallPrintLabelForm
        :currshowlist.sync="showSmallPrintLabelForm"
        :printLabelInfo="printLabelInfo"
      />
      <WarehousingLabelForm
        :currshowlist.sync="showWarehousingPrintLabelForm"
        :printLabelInfo="printLabelInfo"
      />
      <SmallWarehousingLabelForm
        :currshowlist.sync="showSmallWarehousingPrintLabelForm"
        :printLabelInfo="printLabelInfo"
      />
    </basic-container>
  </div>
</template>

<script>
import { realTimeStockPage } from '@/api/warehouse/stock'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table'
import StockTable from './stock-table'
import PrintLabelForm from './print-label-form.vue'
import SmallPrintLabelForm from './small-print-label-form.vue'
import WarehousingLabelForm from './warehousing-label-form.vue'
import SmallWarehousingLabelForm from './small-warehousing-label-form.vue'
import { dateFormat } from '@/util/date'
import { instorage } from '@/api/scm/common'
export default {
  data() {
    return {
      paramObj: {},
      stockVisible: false,
      ajaxFun: realTimeStockPage,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: true,
        url: '/mes/stock/upload'
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            width: '100',
            minWidth: '100',
            prop: 'factoryName',
            label: '工厂',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'partNo',
            label: '零件号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            propVal: this.$route.query.partNo
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'partName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'warehouseName',
            label: '仓库',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'locationNo',
            label: '库位号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'locationName',
            label: '库位名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'systemNo',
            label: '系统编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'partBatchNo',
            label: 'SN号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'reelNumber',
            label: '载具编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'startMetre',
            label: '起始米标',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'endMetre',
            label: '截止米标',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'outerColor',
            label: '外护颜色',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'insulationColor',
            label: '绝缘颜色',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'customerOrderNo',
            label: '销售订单号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'mpsNo',
            label: '主生产计划号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'moNo',
            label: '车间订单号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'stockQuantity',
            label: '库存数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'reserveQuantity',
            label: '预留数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '120',
            prop: 'availableStockQuantity',
            label: '可用库存数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'unit',
            label: '单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '120',
            prop: 'sstockQuantity',
            label: '库存数量2',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '120',
            prop: 'savailableStockQuantity',
            label: '可用库存数量2',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'sunit',
            label: '单位2',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'status',
            label: '状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'ifsBatchNo',
            label: 'IFS批次号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'sourceName',
            label: '来源',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: [
          {
            text: '移库',
            type: 'primary',
            fun: this.moveStock
          },
          {
            text: '大标签',
            type: 'primary',
            fun: this.printLabel
          },
          {
            text: '成品标签1',
            type: 'primary',
            fun: this.warehousingPrint
          },
          {
            text: '成品标签2',
            type: 'primary',
            fun: this.warehousingSmalllPrint
          }
        ]
      },
      addOrUpdateVisible: false,
      showPrintLabelForm: false,
      showSmallPrintLabelForm: false,
      printLabelInfo: null,
      showWarehousingPrintLabelForm: false,
      showSmallWarehousingPrintLabelForm: false
    }
  },
  components: {
    ttable,
    StockTable,
    PrintLabelForm,
    SmallPrintLabelForm,
    WarehousingLabelForm,
    SmallWarehousingLabelForm
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  activated() {
    this.paramObj = {
      partNo: this.$route.query.partNo
    }
    this.getData()
  },
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.warehouseStockTable.getDataList()
    },
    // table自带事件
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    moveStock() {
      if (this.multipleSelection && this.multipleSelection.length > 0) {
        // 判断一下剩余数量是否大于0
        for (let i = 0, len = this.multipleSelection.length; i < len; i++) {
          if (this.multipleSelection[i].availableStockQuantity <= 0) {
            this.$message.error('请选择可用库存数量大于0的库存')
            return
          }
        }
        this.stockVisible = true
        this.$nextTick(() => {
          this.$refs.stock.init(this.multipleSelection)
        })
      } else {
        this.$message.error('请选择实时库存')
      }
    },
    printLabel() {
      if (this.multipleSelection && this.multipleSelection.length > 0) {
        if (this.multipleSelection && this.multipleSelection.length === 1) {
          this.showPrintLabelForm = true
          this.printLabelInfo = {
            partId: this.multipleSelection[0].partId,
            partNo: this.multipleSelection[0].partNo,
            partName: this.multipleSelection[0].partName,
            outBatchNo: this.multipleSelection[0].partBatchNo,
            ifsBatchNo: this.multipleSelection[0].ifsBatchNo,
            productQty: this.multipleSelection[0].stockQuantity,
            lotTrackingIfs: this.multipleSelection[0].lotTrackingIfs,
            startMeterMark: this.multipleSelection[0].startMetre,
            endMeterMark: this.multipleSelection[0].endMetre,
            unit: this.multipleSelection[0].unit,
            customerOrderNo: null,
            customerName: null,
            operationName: null,
            workstationName: null,
            grossWeight: null,
            netWeight: null,
            theoryWeight: null,
            segmentDesc: null,
            reelNumber: this.multipleSelection[0].reelNumber,
            reelWeight: null,
            nowTime: dateFormat(new Date()),
            productionPerson: null,
            remark: null
          }
        } else {
          this.$message.error('只能选择一条实时库存')
        }
      } else {
        this.$message.error('请选择实时库存')
      }
    },
    printSmallLabel() {
      if (this.multipleSelection && this.multipleSelection.length > 0) {
        if (this.multipleSelection && this.multipleSelection.length === 1) {
          this.showSmallPrintLabelForm = true
          this.printLabelInfo = {
            partId: this.multipleSelection[0].partId,
            partNo: this.multipleSelection[0].partNo,
            partName: this.multipleSelection[0].partName,
            outBatchNo: this.multipleSelection[0].partBatchNo,
            productQty: this.multipleSelection[0].stockQuantity,
            lotTrackingIfs: this.multipleSelection[0].lotTrackingIfs,
            unit: this.multipleSelection[0].unit,
            customerOrderNo: null,
            customerName: null,
            operationName: null,
            workstationName: null,
            grossWeight: null,
            netWeight: null,
            theoryWeight: null,
            segmentDesc: null,
            reelNumber: this.multipleSelection[0].reelNumber,
            reelWeight: null,
            nowTime: dateFormat(new Date()),
            productionPerson: null,
            remark: null
          }
        } else {
          this.$message.error('只能选择一条实时库存')
        }
      } else {
        this.$message.error('请选择实时库存')
      }
    },
    // 成品标签1
    warehousingPrint() {
      if (this.multipleSelection && this.multipleSelection.length > 0) {
        if (this.multipleSelection && this.multipleSelection.length === 1) {
          this.showWarehousingPrintLabelForm = true
          this.printLabelInfo = {
            partId: this.multipleSelection[0].partId,
            partNo: this.multipleSelection[0].partNo,
            partName: this.multipleSelection[0].partName,
            outBatchNo: this.multipleSelection[0].partBatchNo,
            ifsBatchNo: this.multipleSelection[0].ifsBatchNo,
            productQty: this.multipleSelection[0].stockQuantity,
            lotTrackingIfs: this.multipleSelection[0].lotTrackingIfs,
            unit: this.multipleSelection[0].unit,
            segmentDesc: null,
            specificationAndMode: this.multipleSelection[0].partName,
            cusMaterialCode: this.multipleSelection[0].cusMaterialCode,
            productionTime: null
          }
        } else {
          this.$message.error('只能选择一条实时库存')
        }
      } else {
        this.$message.error('请选择实时库存')
      }
    },
    // 成品标签2
    warehousingSmalllPrint() {
      if (this.multipleSelection && this.multipleSelection.length > 0) {
        if (this.multipleSelection && this.multipleSelection.length === 1) {
          this.showSmallWarehousingPrintLabelForm = true
          this.printLabelInfo = {
            partId: this.multipleSelection[0].partId,
            partNo: this.multipleSelection[0].partNo,
            partName: this.multipleSelection[0].partName,
            outBatchNo: this.multipleSelection[0].partBatchNo,
            ifsBatchNo: this.multipleSelection[0].ifsBatchNo,
            productQty: this.multipleSelection[0].stockQuantity,
            lotTrackingIfs: this.multipleSelection[0].lotTrackingIfs,
            unit: this.multipleSelection[0].unit
          }
        } else {
          this.$message.error('只能选择一条实时库存')
        }
      } else {
        this.$message.error('请选择实时库存')
      }
    },
    pushScm() {
      if (this.multipleSelection && this.multipleSelection.length > 0) {
        instorage(this.multipleSelection[0].id).then((response) => {
          this.$message.success('推送SCM成功')
        })
      } else {
        this.$message.error('请选择一条库存')
      }
    }
  }
}
</script>
